@@ -28,14 +28,16 @@
 (require-relative-list
  '("command") "realgud-buffer-")
 
-(declare-function realgud-cmdbuf-debugger-name 'realgud-buffer-command)
-(declare-function realgud-cmdbuf?              'realgud-buffer-command)
+(declare-function realgud-cmdbuf-debugger-name        'realgud-buffer-command)
+(declare-function realgud-cmdbuf?                     'realgud-buffer-command)
+(declare-function realgud-cmdbuf-info-divert-output?= 'realgud-buffer-command)
 (declare-function realgud-backtrace-mode (cmdbuf))
 (declare-function realgud:cmd-backtrace (arg))
 (declare-function realgud-cmdbuf-pat(key))
 (declare-function realgud-cmdbuf-info-in-srcbuf?= (arg))
 (declare-function realgud-get-cmdbuf 'realgud-buffer-helper)
 (declare-function realgud:file-loc-from-line 'realgud-file)
+(declare-function buffer-killed?       'realgud-helper)
 (declare-function realgud:loc-describe 'realgud-loc)
 
 (cl-defstruct realgud-backtrace-info
@@ -209,7 +211,7 @@
     )
   )
 
-(defun realgud-backtrace-moveto-frame (num &optional opt-buffer)
+(defun realgud-backtrace-moveto-frame (num &optional _opt-buffer)
   (if (integerp num)
       (if (realgud-backtrace?)
 	  (let* ((ring (realgud-sget 'backtrace-info 'frame-ring))
@@ -407,6 +409,15 @@ filename, line number, whether the frame is selected as text properties."
 	    ;; FIXME: Remove hack that group 1 is always the frame indicator.
 	    (frame-indicator
 	     (substring stripped-string (match-beginning 1) (match-end 1)))
+	    ;; From https://github.com/realgud/realgud/pull/192
+	    ;; Each frame of backtrace is searched via string-match
+	    ;; invocation and a position of the current frame is
+	    ;; updated via (setq last-pos (match-end 0)) in the end of
+	    ;; the loop. But somewhere in the body of the loop (I do
+	    ;; not know exactly where), there is another call to
+	    ;; string-match and it messes up all positions.
+	    (whole-match-begin (match-beginning 0))
+	    (whole-match-end (match-end 0))
 	    (frame-num-pos)
 
 	    )
@@ -418,7 +429,7 @@ filename, line number, whether the frame is selected as text properties."
 			       (match-end frame-group-pat)))
 	      (setq frame-num (string-to-number frame-num-str))
 	      (setq frame-num-pos (match-beginning frame-group-pat))
-	      (add-to-list 'frame-num-pos-list frame-num-pos t)
+	      (cl-pushnew frame-num-pos frame-num-pos-list)
 	      (add-text-properties (match-beginning frame-group-pat)
 				   (match-end frame-group-pat)
 				   (list 'mouse-face 'highlight
@@ -433,7 +444,7 @@ filename, line number, whether the frame is selected as text properties."
 			       (match-end 0)))
 	    (setq frame-num (cl-incf alt-frame-num))
 	    (setq frame-num-pos (match-beginning 0))
-	    (add-to-list 'frame-num-pos-list frame-num-pos t)
+	    (cl-pushnew frame-num-pos frame-num-pos-list)
 	    (add-text-properties (match-beginning 0) (match-end 0)
 				 (list 'mouse-face 'highlight
 				       'help-echo "mouse-2: goto this frame"
@@ -462,18 +473,18 @@ filename, line number, whether the frame is selected as text properties."
 
 	(when (and (stringp filename) (numberp line-num))
 	  (let ((loc (realgud:file-loc-from-line filename line-num cmdbuf)))
-	    (put-text-property (match-beginning 0) (match-end 0)
+	    (put-text-property whole-match-begin whole-match-end
 			       'loc loc string)
 	    ))
-	(put-text-property (match-beginning 0) (match-end 0)
+	(put-text-property whole-match-begin whole-match-end
 			   'frame-num  frame-num string)
-	(setq last-pos (match-end 0))
+	(setq last-pos whole-match-end)
 
 	(if (string-match frame-indicator-re frame-indicator)
 	  (setq selected-frame-num frame-num))
 	))
 
-    (list string selected-frame-num frame-num-pos-list)
+    (list string selected-frame-num (nreverse frame-num-pos-list))
     )
   )
 
