@@ -1,4 +1,4 @@
-;; Copyright (C) 2010-2011, 2013-2014 Free Software Foundation, Inc
+;; Copyright (C) 2010-2011, 2013-2014, 2016-2017 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <rocky@gnu.org>
 
@@ -23,11 +23,17 @@
   value is associated filesystem string presumably in the
   filesystem")
 
+
 (declare-function realgud:strip         'realgud)
 (declare-function realgud-loc-goto      'realgud-loc)
 (declare-function buffer-killed?        'helper)
 (declare-function compilation-find-file 'compile)
 
+(defcustom realgud-file-find-function 'compilation-find-file
+  "Function to call when we can't easily find file"
+  :type 'function
+  :group 'realgud)
+
 (defun realgud:file-line-count(filename)
   "Return the number of lines in file FILENAME, or nil FILENAME can't be
 found"
@@ -60,7 +66,7 @@ at LINE-NUMBER or nil if it is not there"
 					   &optional cmd-marker source-text bp-num
 					   ;; FIXME: remove ignore-file-re and cover with
 					   ;; find-file-fn.
-					   ignore-file-re find-file-fn)
+					   ignore-file-re find-file-fn directory)
   "Return a realgud-loc for FILENAME and LINE-NUMBER and the
 other optional position information.
 
@@ -76,55 +82,61 @@ problem as best as we can determine."
 
   (unless (and filename (file-readable-p filename))
     (if find-file-fn
-	(setq filename (funcall find-file-fn filename))
+        (setq filename (funcall find-file-fn filename))
       ;; FIXME: Remove the below by refactoring to use the above find-file-fn
       ;; else
       (if (and ignore-file-re (string-match ignore-file-re filename))
-	  (message "tracking ignored for psuedo-file %s" filename)
-	;; else
-	(let ((remapped-filename))
-	  (if (gethash filename realgud-file-remap)
-	      (progn
-		(setq remapped-filename (gethash filename realgud-file-remap))
-		(if (file-exists-p remapped-filename)
-		    (setq filename remapped-filename)
-		  (remhash filename realgud-file-remap)))
-	    ;; else
-	    (progn
-	      (setq remapped-filename
-		    (buffer-file-name
-		     (compilation-find-file (point-marker) filename nil)))
-	      (when (and remapped-filename (file-exists-p remapped-filename))
-		(puthash filename remapped-filename realgud-file-remap)
-		(setq filename remapped-filename)
-		)
-	      )))
-	)
+          (message "tracking ignored for pseudo-file %s" filename)
+        ;; else
+        (let ((remapped-filename))
+          (if (gethash filename realgud-file-remap)
+              (progn
+                (setq remapped-filename (gethash filename realgud-file-remap))
+                (if (file-exists-p remapped-filename)
+                    (setq filename remapped-filename)
+                  (remhash filename realgud-file-remap)))
+            ;; else
+            (let ((found-file (funcall realgud-file-find-function (point-marker) filename directory)))
+                (when found-file
+                  (setq remapped-filename (buffer-file-name found-file))
+                  (when (and remapped-filename (file-exists-p remapped-filename))
+                    (puthash filename remapped-filename realgud-file-remap)
+                    (setq filename remapped-filename)
+                    ))
+                )))
+        )
       ;; FIXME: remove above -----------------------------------.
       ))
   (if filename
       (if (file-readable-p filename)
 	  (if (integerp line-number)
 	      (if (> line-number 0)
-		  (lexical-let ((line-count))
+		  (let ((line-count))
 		    (if (setq line-count (realgud:file-line-count filename))
 			(if (> line-count line-number)
 			    (let* ((column-number
 				    (realgud:file-column-from-string filename
 								    line-number
 								    source-text))
-				   ;; And you thought we'd never get around to
-				   ;; doing something other than validation?
-				   (loc (make-realgud-loc
-					 :num           bp-num
-					 :cmd-marker    cmd-marker
-					 :filename      filename
-					 :line-number   line-number
-					 :column-number column-number
-					 :source-text   source-text
-					 :marker        (make-marker)
-					 )))
-			      loc)
+				   (source-buffer (find-file-noselect filename))
+				   (source-mark))
+
+			      ;; And you thought we'd never get around to
+			      ;; doing something other than validation?
+			      (with-current-buffer source-buffer
+				(goto-char (point-min))
+				;; FIXME also allow column number and byte offset
+				(forward-line (1- line-number))
+				(make-realgud-loc
+				      :num           bp-num
+				      :cmd-marker    cmd-marker
+				      :filename      filename
+				      :line-number   line-number
+				      :column-number column-number
+				      :source-text   source-text
+				      :marker        (point-marker)
+				      )
+				))
 			  ;; else
 			  (format "File %s has only %d lines. (Line %d requested.)"
 				  filename line-count line-number))
