@@ -1,4 +1,4 @@
-;; Copyright (C) 2010, 2012, 2014-2016 Free Software Foundation, Inc
+;; Copyright (C) 2010, 2012, 2014-2016, 2018 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <rocky@gnu.org>
 
@@ -27,53 +27,44 @@
     (define-fringe-bitmap 'hollow-right-triangle
       "\xe0\x90\x88\x84\x84\x88\x90\xe0"))
 
+(defface realgud-debugger-running
+  '((((class color) (min-colors 16) (background light))
+     (:foreground "Green4" :weight bold))
+    (((class color) (min-colors 88) (background dark))
+     (:foreground "Green1" :weight bold))
+    (((class color) (min-colors 16) (background dark))
+     (:foreground "Green" :weight bold))
+    (((class color)) (:foreground "green" :weight bold))
+    (t (:weight bold)))
+  "Face used to highlight debugger run information."
+  :group 'realgud
+  :version "24.3")
+
+(defface realgud-debugger-not-running
+  '((t :inherit font-lock-warning-face))
+  "Face used when debugger or process is not running."
+  :group 'realgud
+  :version "24.3")
+
+
 ;; FIXME: Figure out how to do this as a macro.
 
-(if (equal 'dark (frame-parameter nil 'background-mode))
-    (progn
-      (defface realgud-overlay-arrow1
-	'((t
-	   :foreground "green"
-	   :weight bold))
-	"Fringe face for current position."
-	:group 'realgud)
+(defface realgud-overlay-arrow1
+  '((t :inherit realgud-debugger-running))
+    "Realgud fringe face for current position indicator."
+    :group 'realgud)
 
-      (defface realgud-overlay-arrow2
-	'((t
-	   :foreground "white"
-	   :weight bold))
-	"Fringe face for position one back in fringe."
-	:group 'realgud)
+(defface realgud-overlay-arrow2
+  '((((background  dark)) :foreground "white" :weight bold)
+    (((background light)) :foreground "tan1" :weight bold))
+  "Fringe face for current position."
+  :group 'realgud)
 
-      (defface realgud-overlay-arrow3
-	'((t
-	   :foreground "gray"
-	   :weight bold))
-	"Fringe face for position two back in fringe."
-	:group 'realgud)
-      )
-  ;; else
-  (progn
-    (defface realgud-overlay-arrow1
-      '((t
-	 :foreground "black"
-	 :weight bold))
-      "Fringe face for current position."
-      :group 'realgud)
-
-    (defface realgud-overlay-arrow2
-      '((t
-	 :foreground "gray"
-	 :weight bold))
-      "Fringe face for position one back in fringe."
-      :group 'realgud)
-
-    (defface realgud-overlay-arrow3
-      '((t
-	 :foreground "gainsboro"
-	 :weight bold))
-      "Fringe face for position two back in fringe."
-      :group 'realgud)))
+(defface realgud-overlay-arrow3
+  '((((background  dark)) :foreground "DimGray")
+    (((background light)) :foreground "tan4"))
+  "Fringe face for current position."
+  :group 'realgud)
 
 
 (defvar realgud-overlay-arrow1 nil
