@@ -1,4 +1,4 @@
-;; Copyright (C) 2016 Free Software Foundation, Inc
+;; Copyright (C) 2016-2017 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <rocky@gnu.org>
 
@@ -30,6 +30,16 @@
    (t
     (append (realgud:flatten (car mylist)) (realgud:flatten (cdr mylist))))))
 
+(if (or (< emacs-major-version 24)
+	(and (= emacs-major-version 24) (<= emacs-minor-version 3)))
+    ;; From
+    ;; https://stackoverflow.com/questions/12999530/is-there-a-function-that-joins-a-string-into-a-delimited-string
+    (defun realgud:join-string (list joiner)
+      (mapconcat 'identity list joiner))
+  (progn
+    (require 'subr-x)
+    (defalias 'realgud:join-string 'string-join)))
+
 (defun realgud:canonic-major-mode()
   "Return
     - 'eshell if we are in eshell-mode,
