@@ -1,4 +1,4 @@
-;; Copyright (C) 2015-2016 Free Software Foundation, Inc
+;; Copyright (C) 2015-2017 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <rocky@gnu.org>
 
@@ -16,6 +16,8 @@
 ;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 ;;  `pdb' Main interface to pdb via Emacs
+
+(require 'python) ; for python-shell-interpreter
 (require 'load-relative)
 (require-relative-list '("core" "track-mode") "realgud:pdb-")
 (require-relative-list '("../../common/run")  "realgud:")
@@ -46,6 +48,8 @@ This should be an executable on your path, or an absolute file name."
 (declare-function pdb-query-cmdline    'realgud:pdb-core)
 (declare-function pdb-parse-cmd-args   'realgud:pdb-core)
 (declare-function realgud:run-debugger 'realgud:run)
+(declare-function realgud:run-process  'realgud:core)
+(declare-function realgud:flatten      'realgud-utils)
 
 ;;;###autoload
 (defun realgud:pdb (&optional opt-cmd-line no-reset)
@@ -103,6 +107,32 @@ fringe and marginal icons.
   )
 
 
+;;;###autoload
 (defalias 'pdb 'realgud:pdb)
 
+;;;###autoload
+(defun realgud:pdb-delayed ()
+  "This is like `pdb', but assumes inside the program to be debugged, you
+have a call to the debugger somewhere, e.g. 'from trepan.api import debug; debug()'.
+Therefore we invoke python rather than the debugger initially.
+
+"
+  (interactive)
+  (let* ((initial-debugger python-shell-interpreter)
+	 (actual-debugger "pdb")
+	 (cmd-str (pdb-query-cmdline initial-debugger))
+	 (cmd-args (split-string-and-unquote cmd-str))
+	 ;; XXX: python gets registered as the interpreter rather than
+	 ;; a debugger, and the debugger position (nth 1) is missing:
+	 ;; the script-args takes its place.
+	 (parsed-args (pdb-parse-cmd-args cmd-args))
+	 (script-args (nth 1 parsed-args))
+	 (script-name (car script-args))
+	 (parsed-cmd-args
+	  (cl-remove-if 'nil (realgud:flatten parsed-args))))
+    (realgud:run-process actual-debugger script-name parsed-cmd-args
+			 'realgud:pdb-minibuffer-history)))
+
+(realgud-deferred-invoke-setup "pdb")
+
 (provide-me "realgud-")
