@@ -1,4 +1,4 @@
-;; Copyright (C) 2010-2012, 2014-2016 Free Software Foundation, Inc
+;; Copyright (C) 2010-2012, 2014-2017 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <rocky@gnu.org>
 
@@ -41,9 +41,14 @@ realgud-loc-pat struct")
 (setf (gethash "loc" realgud:trepan2-pat-hash)
       realgud:python-trepan-loc-pat)
 
+;; Regular expression that describes a trepan2 prompt.
+;; Note: the prompt in nested debugging
+;; For example:
+;; (trepan2)
+;; ((trepan2))
 (setf (gethash "prompt" realgud:trepan2-pat-hash)
       (make-realgud-loc-pat
-       :regexp   "^(trepan2) "
+       :regexp   "^(+trepan2)+ "
        ))
 
 ;; Regular expression that describes a trepan2 backtrace line.
@@ -102,6 +107,7 @@ realgud-loc-pat struct")
   "Hash key is command name like 'shell' and the value is
   the trepan2 command to use, like 'python'")
 
+(setf (gethash "eval"  realgud:trepan2-command-hash) "eval %s")
 (setf (gethash "shell" realgud:trepan2-command-hash) "python")
 (setf (gethash "until" realgud:trepan2-command-hash) "continue %l")
 
