@@ -9,6 +9,7 @@
 
 ;; Main interface to trepan2 via Emacs
 
+(require 'python) ; for python-shell-interpreter
 (require 'load-relative)
 (require-relative-list '("../../common/helper") "realgud-")
 (require-relative-list '("../../common/run")    "realgud:")
@@ -26,6 +27,8 @@
 (declare-function trepan2-parse-cmd-args 'realgud:trepan2-core)
 (declare-function trepan2-track-mode     'realgud:pydbgr-track-mode)
 (declare-function realgud:run-debugger   'realgud:run)
+(declare-function realgud:run-process  'realgud:core)
+(declare-function realgud:flatten      'realgud-utils)
 
 ;; -------------------------------------------------------------------
 ;; User-definable variables
@@ -44,6 +47,9 @@ This should be an executable on your path, or an absolute file name."
 ;; The end.
 ;;
 
+;;;###autoload
+(defalias 'trepan2 'realgud:trepan2)
+
 ;;;###autoload
 (defun realgud:trepan2 (&optional opt-cmd-line no-reset)
   "Invoke the trepan2 Python debugger and start the Emacs user interface.
@@ -69,16 +75,15 @@ fringe and marginal icons.
 			opt-cmd-line no-reset)
   )
 
-(defalias 'trepan2 'realgud:trepan2)
-
 ;;;###autoload
 (defun realgud:trepan2-delayed ()
   "This is like `trepan2', but assumes inside the program to be debugged, you
 have a call to the debugger somewhere, e.g. 'from trepan.api import debug; debug()'.
 Therefore we invoke python rather than the debugger initially.
+
 "
   (interactive)
-  (let* ((initial-debugger "python")
+  (let* ((initial-debugger python-shell-interpreter)
 	 (actual-debugger "trepan2")
 	 (cmd-str (trepan2-query-cmdline initial-debugger))
 	 (cmd-args (split-string-and-unquote cmd-str))
@@ -93,6 +98,6 @@ Therefore we invoke python rather than the debugger initially.
     (realgud:run-process actual-debugger script-name parsed-cmd-args
 			 'realgud:trepan2-minibuffer-history)))
 
-(defalias 'trepan2-delayed 'realgud:trepan2-delayed)
+(realgud-deferred-invoke-setup "trepan2")
 
 (provide-me "realgud-")
